@@ -1,5 +1,5 @@
 from assertions.assertions import assert_
-from assertions.solutions.common import assert_all, assert_any, assert_lte, assert_truth
+from assertions.solutions.common import assert_all, assert_any, assert_lte, assert_truth, assert_not_truth
 from assertions.solutions.models import assert_model_equal
 from assertions.solutions.response import assert_attr, assert_json, assert_response_status
 from assertions.validators import validate_json
@@ -10,6 +10,7 @@ __all__ = [
     'assert_any',
     'assert_lte',
     'assert_truth',
+    'assert_not_truth',
     'assert_attr',
     'assert_json',
     'assert_response_status',
